@@ -62,9 +62,7 @@ def list_jobs(
         show_default=True,
         help="Status to filter for",
     ),
-    is_all: bool = Option(
-        False, "-a", "--all", is_flag=True, help="Show all jobs regardless of status"
-    ),
+    is_all: bool = Option(False, "-a", "--all", is_flag=True, help="Show all jobs regardless of status"),
 ):
     """List server jobs"""
     tenant = ctx.obj.session.profile.tenant
@@ -141,7 +139,7 @@ def list_jobs(
                 fmt_date(job["created"]),
                 fmt_date(job["last_modified"]),
                 job.get("result"),
-                heartbeat_txt
+                heartbeat_txt,
             ]
         )
     if tenant:
@@ -272,9 +270,7 @@ def delete_job(
 def shutdown_all(
     ctx: Context,
     is_force: bool = Option(False, "-y", is_flag=True, help="Force a shutdown without a prompt"),
-    is_wait: bool = Option(
-        False, "-w", "--wait", is_flag=True, help="Wait until jobs have been shut down"
-    ),
+    is_wait: bool = Option(False, "-w", "--wait", is_flag=True, help="Wait until jobs have been shut down"),
 ):
     """Shut down all jobs in the current tenant"""
     tenant = ctx.obj.tenant
@@ -312,7 +308,7 @@ def shutdown_all(
                 params=params,
             )
             n = len(resp.json()["jobs"])
-            if n <=0 :
+            if n <= 0:
                 break
             out(f"Waiting for {n} jobs to stop")
             time.sleep(1.0)
@@ -320,7 +316,9 @@ def shutdown_all(
             success(f"{cnt} jobs have been shut down for tenant '{tenant}'", bold=True)
         else:
             out(f"Timeout waiting for {n} jobs to stop", fg="red")
-            out(f"It is possible that there are dead ec2 instances in which case you will need to delete jobs.\nYou can investigate this by running 'kamo nodes list' and then delete jobs with 'kamo jobs delete-all'.")
+            out(
+                f"It is possible that there are dead ec2 instances in which case you will need to delete jobs.\nYou can investigate this by running 'kamo nodes list' and then delete jobs with 'kamo jobs delete-all'."
+            )
 
             sys.exit(1)
     else:
@@ -368,16 +366,17 @@ def delete_all(
     else:
         success(f"{cnt} jobs have been deleted for tenant '{tenant}'", bold=True)
 
+
 @app.command("cleanup")
-def cleanup(
-    ctx: Context
-):
+def cleanup(ctx: Context):
     """Clean up orphaned jobs (with no node running) for the current tenant."""
     tenant = ctx.obj.tenant
     if ctx.obj.is_all:
         tenant = None
     jobs_url = ctx.obj.session.knode_url + f"/jobs"
-    resp = ctx.obj.session.get(jobs_url, params={"tenant": tenant, "start": 0, "end": 100, "status": "running,pending,processing"})
+    resp = ctx.obj.session.get(
+        jobs_url, params={"tenant": tenant, "start": 0, "end": 100, "status": "running,pending,processing"}
+    )
     n = 0
     for job in resp.json()["jobs"]:
         node_id = job["node_id"]
@@ -386,7 +385,7 @@ def cleanup(
             ctx.obj.session.get(url)
             continue
         except ServerError as e:
-            if e.response["status_code"]== 404:
+            if e.response["status_code"] == 404:
                 out(f"Deleting orphaned job {job['job_id']} on node {job['node_id']} in tenant {job['tenant']}")
                 job_url = jobs_url + "/" + job["job_id"]
                 _ = ctx.obj.session.delete(job_url)
@@ -396,14 +395,13 @@ def cleanup(
     else:
         success(f"No orphaned jobs to clean up", bold=True)
 
+
 @app.command("create")
 @check_tenant
 def create_job(
     ctx: Context,
     s3_path: str = Option(None, "--s3", help="Deploy a specific build from S3"),
-    version: str = Option(
-        None, "-v", "--version", help="Version to deploy (or latest)"
-    ),
+    version: str = Option(None, "-v", "--version", help="Version to deploy (or latest)"),
     cpu: int = Option(0, "-c", "--cpu", help="Amount of CPU's to reserve"),
     mem: str = Option("0 GB", "-m", "--mem", help="Amount of memory to reserve"),
     node_id: str = Option(None, "-n", "--node", help="Pick a specific node to run on"),
@@ -415,17 +413,13 @@ def create_job(
         help="Deploy one process per Kamo Volume.",
     ),
     instance_id: str = Option(None, "-i", "--instance-id", help="Level instance ID."),
-    executable: str = Option(
-        None, "-e", "--executable", help="Executable name and path (if not standard)"
-    ),
+    executable: str = Option(None, "-e", "--executable", help="Executable name and path (if not standard)"),
     map_name: str = Option(
         None,
         "--map",
         help="Run a custom map or game mode, injected into the head of the command line",
     ),
-    custom_args: str = Option(
-        "?listen,-server,-NullRHI", "-a", "-args", help="Override default arguments"
-    ),
+    custom_args: str = Option("?listen,-server,-NullRHI", "-a", "-args", help="Override default arguments"),
     is_force: bool = Option(
         False,
         "-y",
@@ -459,7 +453,9 @@ def create_job(
                 volumes_per_map.setdefault(region_map_name, []).append(volume_name)
 
             if map_name not in volumes_per_map:
-                abort(f"Map '{map_name}' not found on DB, only these exist: {list(volumes_per_map.keys())}.\nTry deploy without the --ppv switch to populate the DB.")
+                abort(
+                    f"Map '{map_name}' not found on DB, only these exist: {list(volumes_per_map.keys())}.\nTry deploy without the --ppv switch to populate the DB."
+                )
 
             volumes = " ".join([volume or "main" for volume in volumes_per_map[map_name]])
 
@@ -473,7 +469,9 @@ def create_job(
             abort(f"No builds found")
         if version != "latest":
             if version not in versions:
-                abort(f"Version '{version}' not found for tenant '{tenant}'.\nAvailable versions: {', '.join(versions.keys())}")
+                abort(
+                    f"Version '{version}' not found for tenant '{tenant}'.\nAvailable versions: {', '.join(versions.keys())}"
+                )
         else:
             version = list(versions.keys())[0]
         s3_path = versions[version]["s3_path"]
@@ -506,7 +504,6 @@ def create_job(
         # Add all the volumes on a single node
         args.append(f"-kamovolumes={volumes}")
 
-
     if process_per_volume:
         launches = volumes.split(" ")
     else:
@@ -598,6 +595,7 @@ def list_maps(
         print(json.dumps(instances, indent=4))
     else:
         from textwrap import indent
+
         for instance_id, maps in instances.items():
             if len(instances) > 0:
                 print(f"Instance: {instance_id}")
