@@ -97,6 +97,7 @@ def edit_profile(ctx: Context):
 
     echo("Modify your config and close the file")
     from click import edit
+
     edit(filename=full_filename, require_save=True)
 
 
@@ -104,10 +105,8 @@ def edit_profile(ctx: Context):
 def add_profile(
     ctx: Context,
     profile: str = Option(..., "-p", "--domain", prompt="What would you like to call this profile?"),
-    domain: str = Option(
-        ..., "-d", "--domain", prompt="Domain name of the service (e.g. kamo.io)"
-    ),
-    #tenant: str = Option(..., "-t", "--tenant", prompt="Default tenant (e.g. staging)"),
+    domain: str = Option(..., "-d", "--domain", prompt="Domain name of the service (e.g. kamo.io)"),
+    # tenant: str = Option(..., "-t", "--tenant", prompt="Default tenant (e.g. staging)"),
     api_key: str = Option(..., "-k", "--api-key", prompt="API Key"),
     replace: bool = Option(False, "-r", "--replace", is_flag=True, help="Replace an existing profile"),
     skip_auth: str = Option(
@@ -118,9 +117,7 @@ def add_profile(
     profile = profile.lower()
     if profile in get_profiles() and not replace:
         secho(
-            "Profile '{}' already exists. Use --replace if you want to override it.".format(
-                profile
-            ),
+            "Profile '{}' already exists. Use --replace if you want to override it.".format(profile),
             fg="red",
         )
         return
@@ -149,9 +146,7 @@ def add_profile(
     except InvalidProfile as ex:
         abort(ex)
     set_default_profile(profile)
-    echo(
-        "Profile has been added and is now active. If you want to edit it please run: kamo profile edit."
-    )
+    echo("Profile has been added and is now active. If you want to edit it please run: kamo profile edit.")
     secho("Please select a tenant with 'kamo tenants pick'")
 
 
